@@ -74,7 +74,7 @@ sub AUTOLOAD {
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
     archlibexp => '/usr/lib/perl/5.10',
-    archname => 'i486-linux-gnu-thread-multi',
+    archname => 'i686-linux-gnu-thread-multi',
     cc => 'cc',
     d_readlink => 'define',
     d_symlink => 'define',
@@ -86,7 +86,7 @@ tie %Config, 'Config', {
     ldlibpthname => 'LD_LIBRARY_PATH',
     libpth => '/usr/local/lib /lib /usr/lib /usr/lib64',
     osname => 'linux',
-    osvers => '2.6.42-37-generic',
+    osvers => '2.6.24-28-server',
     path_sep => ':',
     privlibexp => '/usr/share/perl/5.10',
     scriptdir => '/usr/bin',
